==> rl-datepicker-popup-0.0.17.tgz: package/src/datepicker-popup.component.ts <==
import { RlDatePickerInputComponent } from './datepicker-input.component';
import { Component, ElementRef, Input, ViewContainerRef, ViewChild, Output, EventEmitter, OnInit, OnDestroy, DoCheck } from '@angular/core';
import { AbstractControlDirective, NgControl } from '@angular/forms';
import { Observable } from 'rxjs/Observable';

@Component({
    selector: 'rl-datepicker-popup',
    template: `
    <div rlDatepickerPopup> 
        <datepicker [(ngModel)]="dateObject" name="datepicker" [hidden]="!opened" [minDate]="options.minDate" [maxDate]="options.maxDate" [showWeeks]="options.showWeeks" (selectionDone)="opened = false"></datepicker>            
        <div [hidden]="!opened" style="padding: 5px;">
            <span class="btn-group pull-left">       
                <button type="button" class="btn btn-sm btn-info" (click)="setToToday()">Today</button>
                <button type="button" class="btn btn-sm btn-danger" (click)="clearDate()">Clear</button>
            </span>
            <button type="button" class="btn btn-sm btn-success pull-right" (click)="opened = false">Done</button>
        </div>
    </div>
  `
})

export class RlDatePickerPopupComponent extends RlDatePickerInputComponent {
    @Input() opened: boolean = false;
    @Input() OpenBtn: ElementRef;
    @Output() onDateChange: EventEmitter<Date> = new EventEmitter();

    constructor(el: ElementRef, control: NgControl) {
        super(el, control);
    }

    ngOnInit(): void {
        super.ngOnInit();

        this.control.valueChanges.subscribe(value => {
            this.onDateChange.emit(value);
        });
    }

    ngOnDestroy = () => {
        this.removeEventListener();
        this.onClose.unsubscribe();
        this.onDateChange.unsubscribe();
    }

    public get DatepickerElement(): HTMLElement {
        return <HTMLElement>(<Element>this.LayoutElement.children[0]);
    }
}

==> rl-datepicker-popup-0.0.18.tgz: package/src/datepicker-popup.component.ts <==
import { RlDatePickerInputComponent } from './datepicker-input.component';
import { Component, ElementRef, Input, ViewContainerRef, ViewChild, Output, EventEmitter, OnInit, OnDestroy, DoCheck } from '@angular/core';
import { AbstractControlDirective, NgControl } from '@angular/forms';
import { Observable } from 'rxjs/Observable';

@Component({
    selector: 'rl-datepicker-popup',
    template: `
    <div rlDatepickerPopup> 
        <datepicker [(ngModel)]="dateObject" name="datepicker" [hidden]="!opened" [minDate]="options.minDate" [maxDate]="options.maxDate" [showWeeks]="options.showWeeks" (selectionDone)="selectionDone()"></datepicker>            
        <div [hidden]="!opened" style="padding: 5px;">
            <span class="btn-group pull-left">       
                <button type="button" class="btn btn-sm btn-info" (click)="setToToday()">Today</button>
                <button type="button" class="btn btn-sm btn-danger" (click)="clearDate()">Clear</button>
            </span>
            <button type="button" class="btn btn-sm btn-success pull-right" (click)="opened = false">Done</button>
        </div>
    </div>
  `
})

export class RlDatePickerPopupComponent extends RlDatePickerInputComponent {
    @Input() opened: boolean = false;
    @Input() OpenBtn: ElementRef;
    @Output() onDateChange: EventEmitter<Date> = new EventEmitter();

    constructor(el: ElementRef, control: NgControl) {
        super(el, control);
    }

    ngOnInit(): void {
        super.ngOnInit();

        this.control.valueChanges.subscribe(value => {
            this.onDateChange.emit(value);
        });
    }

    ngOnDestroy = () => {
        this.removeEventListener();
        this.onClose.unsubscribe();
        this.onDateChange.unsubscribe();
    }

    public get DatepickerElement(): HTMLElement {
        return <HTMLElement>(<Element>this.LayoutElement.children[0]);
    }
}
